#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var commander_1 = __importDefault(require("commander"));
var chalk_1 = __importDefault(require("chalk"));
var inquirer_1 = __importDefault(require("inquirer"));
var generate_1 = __importDefault(require("./command/generate"));
var config = require("../package.json");
var version = config.version || "unknown";
commander_1.default.version(version);
/**
 * Generate cdn url with hash
 * > ihashgen generate <cdn_url>
 * > ihashgen g <cdn_url>
 */
commander_1.default
    .command("generate <cdn_url>")
    .alias("g")
    .description("generate links based on url given")
    .option("-t, --type [css/js]", "specify file type (css/js)")
    .option("-a, --algo [sha384]", "specify hashing algorithm (sha384)")
    .action(function (d, args) {
    return generate_1.default(d, args);
});
console.log(chalk_1.default.bgBlue("ihashgen v" + version));
// nothing entered
if (process.argv.length === 2) {
    var questions = [
        {
            type: "list",
            name: "fileType",
            message: "Choose file type",
            choices: ["css", "js"]
        },
        {
            type: "list",
            name: "hashType",
            message: "Choose hashing algorithm use",
            choices: ["sha384"]
        },
        {
            type: "input",
            name: "cdnUrl",
            message: "Enter cdn url:"
        }
    ];
    var inq = inquirer_1.default.prompt(questions);
    inq.then(function (answer) {
        return generate_1.default(answer.cdnUrl, {
            type: answer.fileType,
            algo: answer.hashType
        });
    });
}
commander_1.default.parse(process.argv);
